/*
 * JBoss, Home of Professional Open Source
 * Copyright 2012, Red Hat, Inc. and/or its affiliates, and individual
 * contributors by the @authors tag. See the copyright.txt in the 
 * distribution for a full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package guiaModernismo.dao;

import guiaModernismo.model.Busqueda;

import java.util.ArrayList;
import java.util.List;
import java.util.logging.Logger;

import javax.ejb.Stateless;
import javax.inject.Inject;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;

// The @Stateless annotation eliminates the need for manual transaction demarcation
@Stateless
public class BusquedaDAO {
	
    @Inject
    private Logger log;

    @PersistenceContext(unitName="primary")
    private EntityManager em;
   
    public EntityManager returnEM(){
    	
    	return em;
    }
    
    public void register(Busqueda busqueda) throws Exception {

        log.info("Registro :" + busqueda.getId());
        em.merge(busqueda);
        
    }
    
    public void remove(Busqueda busqueda) throws Exception {
    	
        log.info("Borrado :" + busqueda.getId());
        Busqueda newEntity = em.getReference(Busqueda.class, busqueda.getId());
        em.remove(newEntity);
        
    }
    
    public Busqueda findById(Integer id) {
		
		try {
			Busqueda media = em.find(Busqueda.class, id);
			
			return media;
		} catch (RuntimeException re) {
			
			throw re;
		}
	}
    
    /**
     * @param txtSearch
     * @return
     */
    public List<Busqueda> findByTxtSearch(String txtSearch) {

		List<Busqueda> lBusqueda = new ArrayList<Busqueda>();

		String sQuery = "from Busqueda b where LOWER(b.texto) like '%"
				+ txtSearch
				+ "%'";
				
		Query query = em.createQuery(sQuery);

		lBusqueda = query.getResultList();

		return lBusqueda;
		
	}
}
