/*
 * JBoss, Home of Professional Open Source
 * Copyright 2012, Red Hat, Inc. and/or its affiliates, and individual
 * contributors by the @authors tag. See the copyright.txt in the 
 * distribution for a full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package guiaModernismo.dao;

import guiaModernismo.model.Contacto;

import java.util.logging.Logger;

import javax.ejb.Stateless;
import javax.inject.Inject;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;

// The @Stateless annotation eliminates the need for manual transaction demarcation
@Stateless
public class ContactoDAO {
	
    @Inject
    private Logger log;

    @PersistenceContext(unitName="primary")
    private EntityManager em;
    
    public EntityManager returnEM(){
    	
    	return em;
    }
    
    public void register(Contacto contacto) throws Exception {
    	
        log.info("Registro :" + contacto.getId());
        em.merge(contacto);
        
    }
    
    public void remove(Contacto contacto) throws Exception {
    	
        log.info("Borrado :" + contacto.getId());
        Contacto newEntity = em.getReference(Contacto.class, contacto.getId());
        em.remove(newEntity);
        
    }
    
    public Contacto findById(Integer id) {
		
		try {
			Contacto contacto = em.find(Contacto.class, id);
			
			return contacto;
		} catch (RuntimeException re) {
			
			throw re;
		}
	}
}
