/*
 * JBoss, Home of Professional Open Source
 * Copyright 2012, Red Hat, Inc. and/or its affiliates, and individual
 * contributors by the @authors tag. See the copyright.txt in the 
 * distribution for a full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package guiaModernismo.dao;

import guiaModernismo.model.Busqueda;
import guiaModernismo.model.Media;

import java.util.ArrayList;
import java.util.List;
import java.util.logging.Logger;

import javax.ejb.Stateless;
import javax.inject.Inject;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;

// The @Stateless annotation eliminates the need for manual transaction demarcation
@Stateless
public class MediaDAO {
	
    @Inject
    private Logger log;

    @PersistenceContext(unitName="primary")
    private EntityManager em;
    
    public EntityManager returnEM(){
    	
    	return em;
    }
    
    public void register(Media media) throws Exception {
    	
        log.info("Registro :" + media.getId());
        em.merge(media);
        
    }
    
    public void remove(Media media) throws Exception {
    	
        log.info("Borrado :" + media.getId());
        Media newEntity = em.getReference(Media.class, media.getId());
        em.remove(newEntity);
        
    }
    
    public Media findById(Integer id) {
		
		try {
			Media media = em.find(Media.class, id);
			
			return media;
		} catch (RuntimeException re) {
			
			throw re;
		}
	}
    
    public List<Media> findFotos() {

		List<Media> lMedia = new ArrayList<Media>();

		String sQuery = "from Media m where m.tipo = 'FOTO'";
				
		Query query = em.createQuery(sQuery);

		lMedia = query.getResultList();

		return lMedia;
		
	}
    
  
}
