/*
 * JBoss, Home of Professional Open Source
 * Copyright 2012, Red Hat, Inc. and/or its affiliates, and individual
 * contributors by the @authors tag. See the copyright.txt in the 
 * distribution for a full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package guiaModernismo.dao;

import guiaModernismo.model.Paginaidioma;

import java.util.ArrayList;
import java.util.List;
import java.util.logging.Logger;

import javax.ejb.Stateless;
import javax.inject.Inject;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Root;

// The @Stateless annotation eliminates the need for manual transaction demarcation
@Stateless
public class PaginaIdiomaDAO {
	
	

    @Inject
    private Logger log;

    
    @PersistenceContext(unitName="primary")
    private EntityManager em;
    
 
    
  
    public EntityManager returnEM(){
    	
    	return em;
    }
    
    public void register(Paginaidioma paginaidioma) throws Exception {
    	
    	
    	
        log.info("Registro :" + paginaidioma.getId());
        em.merge(paginaidioma);
        
    }
    
    public void remove(Paginaidioma paginaidioma) throws Exception {
    	
        log.info("Borrado :" + paginaidioma.getId());
        Paginaidioma newEntity = em.getReference(Paginaidioma.class, paginaidioma.getId());
        em.remove(newEntity);
        
    }
    
    public Paginaidioma findById(Integer id) {
		
		try {
			Paginaidioma contenidoPagina = em.find(Paginaidioma.class, id);
			
			return contenidoPagina;
		} catch (RuntimeException re) {
			
			throw re;
		}
	}
    
    public List<Paginaidioma> findByIdioma(String idioma) {

		CriteriaBuilder cb = em.getCriteriaBuilder();
		CriteriaQuery<Paginaidioma> criteria = cb.createQuery(Paginaidioma.class);
		Root<Paginaidioma> targeta = criteria.from(Paginaidioma.class);
		    
		criteria.select(targeta).where(cb.equal(targeta.get("idioma"), idioma));
		
		List<Paginaidioma> lPaginaidioma = new ArrayList<Paginaidioma>();
		    
		lPaginaidioma =  em.createQuery(criteria).getResultList();
		
		if (lPaginaidioma.isEmpty()) {
			return null;
		}else{
			return lPaginaidioma;
		}
	}
    
  
}
